@@ -26,7 +26,6 @@ from oslo_utils import timeutils
 from designate import dnsutils
 from designate import exceptions
 from designate import objects
-from designate import utils
 from designate.worker.tasks import base
 
 LOG = logging.getLogger(__name__)
@@ -44,13 +43,14 @@ class ZoneActionOnTarget(base.Task):
     :return: Success/Failure of the target action (bool)
     """
 
-    def __init__(self, executor, context, zone, target):
+    def __init__(self, executor, context, zone, target, zone_params):
         super(ZoneActionOnTarget, self).__init__(executor)
         self.zone = zone
         self.action = zone.action
         self.target = target
         self.context = context
         self.task_name = 'ZoneActionOnTarget-%s' % self.action.title()
+        self.zone_params = zone_params
 
     def __call__(self):
         LOG.debug(
@@ -70,7 +70,8 @@ class ZoneActionOnTarget(base.Task):
                     self.target.backend.create_zone(self.context, self.zone)
                     SendNotify(self.executor, self.zone, self.target)()
                 elif self.action == 'DELETE':
-                    self.target.backend.delete_zone(self.context, self.zone)
+                    self.target.backend.delete_zone(self.context, self.zone,
+                                                    self.zone_params)
                 else:
                     self.target.backend.update_zone(self.context, self.zone)
                     SendNotify(self.executor, self.zone, self.target)()
@@ -195,15 +196,17 @@ class ZoneActor(base.Task):
              of targets (bool)
     """
 
-    def __init__(self, executor, context, pool, zone):
+    def __init__(self, executor, context, pool, zone, zone_params=None):
         super(ZoneActor, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
+        self.zone_params = zone_params
 
     def _execute(self):
         results = self.executor.run([
-            ZoneActionOnTarget(self.executor, self.context, self.zone, target)
+            ZoneActionOnTarget(self.executor, self.context, self.zone, target,
+                               self.zone_params)
             for target in self.pool.targets
         ])
         return results
@@ -250,13 +253,15 @@ class ZoneAction(base.Task):
              number of nameservers (bool)
     """
 
-    def __init__(self, executor, context, pool, zone, action):
+    def __init__(self, executor, context, pool, zone, action,
+                 zone_params=None):
         super(ZoneAction, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
         self.action = action
         self.task_name = 'ZoneAction-%s' % self.action.title()
+        self.zone_params = zone_params
 
     def _wait_for_nameservers(self):
         """
@@ -266,7 +271,7 @@ class ZoneAction(base.Task):
 
     def _zone_action_on_targets(self):
         actor = ZoneActor(
-            self.executor, self.context, self.pool, self.zone
+            self.executor, self.context, self.pool, self.zone, self.zone_params
         )
         return actor()
 
@@ -789,11 +794,10 @@ class RecoverShard(base.Task):
         # Include things that have been hanging out in PENDING
         # status for longer than they should
         # Generate the current serial, will provide a UTC Unix TS.
-        current = utils.increment_serial()
         stale_criterion = {
             'shard': "BETWEEN %s,%s" % (self.begin_shard, self.end_shard),
             'status': 'PENDING',
-            'serial': "<%s" % (current - self.max_prop_time)
+            'serial': "<%s" % (timeutils.utcnow_ts() - self.max_prop_time)
         }
 
         stale_zones = self.storage.find_zones(self.context, stale_criterion)
